BannerDataModel class

Annotations
  • @freezed

Constructors

BannerDataModel({@Default.new('') String campaign, @Default.new('') String startDate, @Default.new('') String endDate, @Default.new('') String image, @Default.new('') String link, @Default.new('') String category, @Default.new('') String miniApp, @Default.new('') String miniAppData, @Default.new(0) int actionButton})
const
factory
BannerDataModel.fromJson(Map<String, dynamic> json)
factory

Properties

actionButton int
no setterinherited
campaign String
no setterinherited
category String
no setterinherited
copyWith → $BannerDataModelCopyWith<BannerDataModel>
no setterinherited
endDate String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
image String
no setterinherited
no setterinherited
miniApp String
no setterinherited
miniAppData String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited