BannerModel class

Annotations
  • @freezed

Constructors

BannerModel({@Default.new(0) int id, @Default.new(0) int retailerId, @Default.new(0) int industry, @Default.new(0) int zone, @Default.new(0) int bannerId, @Default.new(0) int brandType, @Default.new(false) bool display, @Default.new(BannerDataModel()) BannerDataModel banner})
const
factory
BannerModel.fromJson(Map<String, dynamic> json)
factory

Properties

no setterinherited
bannerId int
no setterinherited
brandType int
no setterinherited
copyWith → $BannerModelCopyWith<BannerModel>
no setterinherited
display bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
industry int
no setterinherited
retailerId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited