APIResponse class

Annotations
  • @freezed

Constructors

APIResponse({@Default.new({}) Map<String, dynamic> data})
const
factory

Properties

copyWith → $APIResponseCopyWith<APIResponse>
no setterinherited
data Map<String, dynamic>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited